![Python package](https://github.com/Pythocrates/SPyKeS/workflows/Python%20package/badge.svg)
[![codecov](https://codecov.io/gh/Pythocrates/SPyKeS/branch/master/graph/badge.svg)](https://codecov.io/gh/Pythocrates/SPyKeS)
[![Test Coverage](https://api.codeclimate.com/v1/badges/0d092f8ca82f91264651/test_coverage)](https://codeclimate.com/github/Pythocrates/SPyKeS/test_coverage)
[![Maintainability](https://api.codeclimate.com/v1/badges/0d092f8ca82f91264651/maintainability)](https://codeclimate.com/github/Pythocrates/SPyKeS/maintainability)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Code Quality Score](https://www.code-inspector.com/project/13444/score/svg)](https://frontend.code-inspector.com/public/project/13444/SPyKeS/dashboard)
[![Code Grade](https://www.code-inspector.com/project/13444/status/svg)](https://frontend.code-inspector.com/public/project/13444/SPyKeS/dashboard)
# SPyKeS
Simple Python Key Store

SPyKeS is a simple Python implementation of https://github.com/42ways/simple-keystore.
